Stan Math Library: Class Members - Functions

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

- All
- Functions
- Variables
- Typedefs
- Enumerator
- Related Functions

- a
- b
- c
- d
- e
- f
- g
- h
- i
- j
- l
- m
- n
- o
- p
- q
- r
- s
- t
- v
- w
- ~

### - t -

- tangent() : stan::math::fvar< T >

[ Stan Home Page ] © 2011–2016, Stan Development Team.